@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2017,2019-2020 Aurimas Cernius
+ * Copyright (C) 2011-2014,2017,2019-2020,2022 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -49,9 +49,9 @@ const Glib::ustring & NoteDataBufferSynchronizerBase::text()
   return data().text();
 }
 
-void NoteDataBufferSynchronizerBase::set_text(const Glib::ustring & t)
+void NoteDataBufferSynchronizerBase::set_text(Glib::ustring && t)
 {
-  data().text() = t;
+  data().text() = std::move(t);
 }
 
 
@@ -113,9 +113,9 @@ Glib::ustring NoteBase::parse_text_content(const Glib::ustring & content)
 }
 
 
-NoteBase::NoteBase(const Glib::ustring & filepath, NoteManagerBase & _manager)
+NoteBase::NoteBase(const Glib::ustring && filepath, NoteManagerBase & _manager)
   : m_manager(_manager)
-  , m_file_path(filepath)
+  , m_file_path(std::move(filepath))
   , m_enabled(true)
 {
 }
@@ -141,16 +141,16 @@ const Glib::ustring & NoteBase::get_title() const
   return data_synchronizer().data().title();
 }
 
-void NoteBase::set_title(const Glib::ustring & new_title)
+void NoteBase::set_title(Glib::ustring && new_title)
 {
-  set_title(new_title, false);
+  set_title(std::move(new_title), false);
 }
 
-void NoteBase::set_title(const Glib::ustring & new_title, bool from_user_action)
+void NoteBase::set_title(Glib::ustring && new_title, bool from_user_action)
 {
   if(data_synchronizer().data().title() != new_title) {
-    Glib::ustring old_title = data_synchronizer().data().title();
-    data_synchronizer().data().title() = new_title;
+    Glib::ustring old_title = std::move(data_synchronizer().data().title());
+    data_synchronizer().data().title() = std::move(new_title);
 
     if(from_user_action) {
       process_rename_link_update(old_title);
@@ -177,13 +177,13 @@ void NoteBase::process_rename_link_update(const Glib::ustring & old_title)
   queue_save(CONTENT_CHANGED);
 }
 
-void NoteBase::rename_without_link_update(const Glib::ustring & newTitle)
+void NoteBase::rename_without_link_update(Glib::ustring && newTitle)
 {
   if(data_synchronizer().data().title() != newTitle) {
-    data_synchronizer().data().title() = newTitle;
+    data_synchronizer().data().title() = std::move(newTitle);
 
     // HACK:
-    signal_renamed(shared_from_this(), newTitle);
+    signal_renamed(shared_from_this(), data_synchronizer().data().title());
 
     queue_save(CONTENT_CHANGED); // TODO: Right place for this?
   }
@@ -313,9 +313,9 @@ Glib::ustring NoteBase::get_complete_note_xml()
   return m_manager.note_archiver().write_string(data_synchronizer().synchronized_data());
 }
 
-void NoteBase::set_xml_content(const Glib::ustring & xml)
+void NoteBase::set_xml_content(Glib::ustring && xml)
 {
-  data_synchronizer().set_text(xml);
+  data_synchronizer().set_text(std::move(xml));
 }
 
 Glib::ustring NoteBase::text_content()
